/*-
 * ========================LICENSE_START=================================
 * O-RAN-SC
 * %%
 * Copyright (C) 2019 AT&T Intellectual Property
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ========================LICENSE_END===================================
 */
package org.oransc.ric.portal.dashboard.config;

import java.lang.invoke.MethodHandles;

import org.onap.portalsdk.core.onboarding.crossapi.PortalRestAPIProxy;
import org.onap.portalsdk.core.onboarding.util.PortalApiConstants;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.web.servlet.ServletRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Profile;

@Configuration
@Profile("!test")
public class PortalApiConfiguration {

    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());

    /**
     * Instantiates the EPSDK-FW servlet that implements the API called by Portal.
     * Needed because this app is not configured to scan the EPSDK-FW packages;
     * there's also a chance that Spring-Boot does not automatically
     * process @WebServlet annotations.
     *
     * @return Servlet registration bean for the Portal Rest API proxy servlet.
     */
    @Bean
    public ServletRegistrationBean<PortalRestAPIProxy> portalApiProxyServletBean() {
        logger.debug("portalApiProxyServletBean");
        PortalRestAPIProxy servlet = new PortalRestAPIProxy();
        final ServletRegistrationBean<PortalRestAPIProxy> servletBean =
            new ServletRegistrationBean<>(servlet, PortalApiConstants.API_PREFIX + "/*");
        servletBean.setName("PortalRestApiProxyServlet");
        return servletBean;
    }

}
